/**
 * \file
 * \author Matthias Riedl
 * \brief covers the functionality of a limits checker
 * \verbatim
 * $id
 * \endverbatim
 */

//compiler
#include "stdafx.h"
#include <stdio.h>

// std

// own
#include "limits_alarm_impl.h"
#include "hysteresis_impl.h"

void
print_result(const limits_alarm& alert)
{
  float x, h, l, eps;

  alert.get_input(x, h, l, eps);

  printf("Process Value:\t\t%5.3f\n", x);
  printf("High Limit:\t\t%5.3f\n", h);
  printf("Low Limit:\t\t%5.3f\n", l);
  printf("Confidence interval:\t%5.3f\n", eps);

  if (alert.get_result())
  {
    if (alert.is_high_alert())
      printf("Value exceeds the high limit\n");
    else
      printf("Value falls below the low limit\n");  
  } // if
  else
    printf("Value is inside the limits\n");

} // print_result

int main(int argc, char* argv[])
{
  // one object for limits checking
  limits_alarm_impl alert;

  // two objects for hysteresis checking
  hysteresis_impl lower;
  hysteresis_impl upper;

  // setting the inputs
  alert.set_input(4.0, 5.0, 3.0, 0.5);

  // calling the algorithm of the FB
  alert.en();

  // eval the result
  print_result(alert);

  // setting the inputs
  alert.set_input(6.0, 5.0, 3.0, 0.5);

  // calling the algorithm of the FB
  alert.en();

  // eval the result
  print_result(alert);


	return 0;
} // main
