/**
 * \file
 * \author Matthias Riedl
 * \brief covers the functionality of a hysteresis FB
 * \improved by usage of abstract interfaces
 * \verbatim
 * $id
 * \endverbatim
 */

#ifndef __HYSTERESIS_H
#define __HYSTERESIS_H

//com

//std

// own
#include "fb.h"

/**
 * Function Block interface for hysteresis calculation
 */
class hysteresis: public fb
{
public:
  /**
   * Sets the input values of the function block. 
   * Should be called before \ref en().
   * \param xin1 - value of xin1 
   * \param xin2 - value of xin2
   * \param eps - value of eps 
   */ 
  virtual void  set_input(const float xin1, const float xin2, const float eps) = 0;
  /**
   * Delivers the result of the algorithm.
   * Should be called after \ref en().
   * return true - value exceeds the limit. 
   */
  virtual bool  get_result() = 0;
}; // hysteresis

#endif  //__HYSTERESIS_H
