/**
 * \file
 * \author Matthias Riedl
 * \brief covers the functionality of a hysteresis FB
 * \improved by usage of abstract interfaces
 * \verbatim
 * $id
 * \endverbatim
 */

#ifndef __HYSTERESIS_IMPL_H
#define __HYSTERESIS_IMPL_H

//com

//std

// own
#include "hysteresis.h"

/**
 * Function Block implementation for hysteresis calculation
 */
class hysteresis_impl: public hysteresis
{
  // no copy or assignment operations
  hysteresis_impl(const hysteresis_impl& obj);
  hysteresis_impl& operator=(const hysteresis_impl& obj);
public:
	/** \name Construct/Destructor */
	//! \{
  	/**
   	 * Constructor
	 */
	hysteresis_impl();
	/**
	 * Destructor
	 */
	virtual ~hysteresis_impl();
	//! \}

  /** \name implementation of abstract interface 'FB'
  //! \{
	/**
	 * Perfoms the algorithm of the function block
	 */
	virtual void 	en();
  //! \}


  /** \name implementation of abstract interface 'hysteresis'
  //! \{
  /**
   * Sets the input values of the function block. 
   * Should be called before \ref en().
   * \param xin1 - value of xin1 
   * \param xin2 - value of xin2
   * \param eps - value of eps 
   */ 
  virtual void  set_input(const float xin1, const float xin2, const float eps);
  /**
   * Delivers the result of the algorithm.
   * Should be called after \ref en().
   * return true - value exceeds the limit. 
   */
  virtual bool  get_result();
  //! \}
private:
  float	m_xin1; /**< input xin1 */
	float	m_xin2; /**< input xin2 */
	float	m_eps; /**< confidential interval */

	bool	m_q; /**< output; true - values are inside the confidence interval */
}; // hysteresis_impl

#endif  //__HYSTERESIS_IMPL_H
